# Builtin Plugins

The Elastic-AI.creator comes bundled with a few plugins.

```{toctree}
counter
padding
shift_register
sliding_window
striding_shift_register
skeleton
lutron
combinatorial
grouped_filter
```
